import getLog from './get-log';

const deleteSecret = async (pool, selector) => {
  const log = getLog('secretsManager:deleteSecret');
  log.debug(`removing secret from the database`);
  const {
    databaseName,
    secretsTableName,
    escapeId,
    escape,
    executeStatement
  } = pool; // TODO: refactor

  if (!secretsTableName || !escapeId || !escape || !databaseName || !executeStatement) {
    const error = Error(`adapter pool was not initialized properly!`);
    log.error(error.message);
    log.verbose(error.stack || error.message);
    throw error;
  }

  log.verbose(`selector: ${selector}`);
  log.verbose(`databaseName: ${databaseName}`);
  log.verbose(`secretsTableName: ${secretsTableName}`);
  const databaseNameAsId = escapeId(databaseName);
  const secretsTableNameAsId = escapeId(secretsTableName);
  const sql = `DELETE FROM ${databaseNameAsId}.${secretsTableNameAsId} 
     WHERE "id"=${escape(selector)}`;
  log.debug(`executing SQL query`);
  await executeStatement(sql);
  log.debug(`query executed successfully`);
};

export default deleteSecret;
//# sourceMappingURL=delete-secret.js.map