"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _getLog = _interopRequireDefault(require("./get-log"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const setSecret = async (pool, selector, secret) => {
  const log = (0, _getLog.default)('secretsManager:setSecret');
  log.debug(`setting secret value within database`);
  const {
    databaseName,
    secretsTableName,
    escape,
    escapeId,
    executeStatement
  } = pool; // TODO: refactor

  if (!secretsTableName || !escapeId || !databaseName || !executeStatement || !escape) {
    const error = Error(`adapter pool was not initialized properly!`);
    log.error(error.message);
    log.verbose(error.stack || error.message);
    throw error;
  }

  log.verbose(`selector: ${selector}`);
  log.verbose(`databaseName: ${databaseName}`);
  log.verbose(`secretsTableName: ${secretsTableName}`);
  const databaseNameAsId = escapeId(databaseName);
  const secretsTableNameAsId = escapeId(secretsTableName); // logging of this sql query can lead to security issues

  const sql = `INSERT INTO ${databaseNameAsId}.${secretsTableNameAsId}("id", "secret") 
    VALUES (${escape(selector)}, ${escape(secret)})`;

  try {
    log.debug(`executing SQL query`);
    await executeStatement(sql);
    log.debug(`query executed successfully`);
  } catch (error) {
    log.error(error.message);
    log.verbose(error.stack);
    throw error;
  }
};

var _default = setSecret;
exports.default = _default;
//# sourceMappingURL=set-secret.js.map